@@ -93,10 +93,28 @@ read_docx <- function(path = NULL) {
   obj$headers <- update_hf_list(part_list = list(), type = "header", package_dir = package_dir)
   obj$footers <- update_hf_list(part_list = list(), type = "footer", package_dir = package_dir)
 
+  if (!file.exists(file.path(package_dir, "word", "comments.xml"))) {
+    file.copy(
+      system.file(package = "officer", "template", "comments.xml"),
+      file.path(package_dir, "word", "comments.xml"),
+      copy.mode = FALSE
+    )
+    obj$content_type$add_override(
+      setNames("application/vnd.openxmlformats-officedocument.wordprocessingml.comments+xml", "/word/comments.xml")
+    )
+  }
+
+  obj$comments <- docx_part$new(
+    package_dir,
+    main_file = "comments.xml",
+    cursor = "/w:comments/*[last()]", body_xpath = "/w:comments"
+  )
+
   if (!file.exists(file.path(package_dir, "word", "footnotes.xml"))) {
     file.copy(
       system.file(package = "officer", "template", "footnotes.xml"),
-      file.path(package_dir, "word", "footnotes.xml")
+      file.path(package_dir, "word", "footnotes.xml"),
+      copy.mode = FALSE
     )
     obj$content_type$add_override(
       setNames("application/vnd.openxmlformats-officedocument.wordprocessingml.footnotes+xml", "/word/footnotes.xml")
@@ -149,15 +167,13 @@ print.rdocx <- function(x, target = NULL, ...) {
     stop(target, " should have '.docx' extension.")
   }
 
-  if (is_windows() && is_office_doc_edited(target)) {
-    stop(
-      target, " is already edited.",
-      " You must close the document in order to be able to write the file."
-    )
+  if (is_windows() && is_doc_open(target)) {
+    stop(target, " is open. To write to this document, please, close it.")
   }
 
   x <- process_sections(x)
 
+  process_comments(x)
   process_footnotes(x)
   process_stylenames(x$doc_obj, x$styles)
   process_links(x$doc_obj, type = "wml")
@@ -183,6 +199,8 @@ print.rdocx <- function(x, target = NULL, ...) {
   int_id <- correct_id(x$doc_obj$get(), int_id)
   # make all id unique for footnote
   int_id <- correct_id(x$footnotes$get(), int_id)
+  # make all id unique for footnote
+  int_id <- correct_id(x$comments$get(), int_id)
   # make all id unique for headers
   for (docpart in x[["headers"]]) {
     int_id <- correct_id(docpart$get(), int_id)
@@ -212,6 +230,7 @@ print.rdocx <- function(x, target = NULL, ...) {
   x$doc_obj$save()
   x$content_type$save()
   x$footnotes$save()
+  x$comments$save()
 
   x$rel$write(file.path(x$package_dir, "_rels", ".rels"))
   write_docx_settings(x)
@@ -679,4 +698,3 @@ docx_current_block_xml <- function( x ){
 docx_body_relationship <- function( x ){
   x$doc_obj$relationship()
 }
-
